/*
 * Copyright (C) 2014-2020 CZ.NIC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations including
 * the two.
 */

#include "src/about.h"
#include "src/common.h"
#include "src/gui/dlg_about.h"
#include "src/gui/dlg_licence.h"
#include "ui_dlg_about.h"

DlgAbout::DlgAbout(QWidget *parent)
    : QDialog(parent),
    m_ui(new (std::nothrow) Ui::DlgAbout)
{
	m_ui->setupUi(this);

	QString title;
	title.append("<div style=\"font-size:22pt;\"><b>" + QString(APP_NAME).toUpper() + "</b></div>");
#ifdef PORTABLE_APPLICATION
	title.append("<div><b>" + tr("Portable version") + "</b></div>");
#endif /* PORTABLE_APPLICATION */
	title.append("<div>" + tr("Free client for Czech eGov data boxes.") + "</div>");
	m_ui->labelTitle->setText(title);

	m_ui->labelVersion->setText("<b>" + tr("Version") + ": " VERSION + "</b>");

	// TODO - it will use in the feature
	m_ui->updateButton->setText(tr("Update to ") + VERSION);
	m_ui->updateButton->setVisible(false);

	// TODO - it will use in the feature
	m_ui->labelDonate->setText("<p><a href=\"" DATOVKA_HOMEPAGE_URL "\">" + tr("Donate a contribution") + "</a>.</p>");
	m_ui->labelDonate->setVisible(false);

	m_ui->homepage->setText("<a href=\"" DATOVKA_HOMEPAGE_URL "\">" + tr("Home Page") + "</a>");
	m_ui->userguide->setText("<a href=\"" DATOVKA_ONLINE_HELP_URL "\">" + tr("User Guide") + "</a>");
	m_ui->faq->setText("<a href=\"" DATOVKA_FAQ_URL "\">" + tr("FAQ") + "</a>");
	m_ui->bestpractice->setText("<a href=\"" DATOVKA_BEST_PRACTICE_URL "\">" + tr("Best Practice") + "</a>");

	QString copyrightHtml("Copyright &copy; 2014–2020 <a href=\"" CZ_NIC_URL "\">CZ.NIC, z. s. p. o.</a>");
	copyrightHtml += "<br/>" + tr("Support") + ": &lt;<a href=\"mailto:" SUPPORT_MAIL "?Subject=[Datovka%20" VERSION "]\">" SUPPORT_MAIL "</a>&gt;";
	m_ui->labelCopy->setText(copyrightHtml);

	QString librariesStr("<b>");
	librariesStr += QObject::tr("Depends on libraries:");
	librariesStr += "</b><br/>";
	m_ui->labelLibs->setText(librariesStr + libraryDependencies().join("<br/>"));

	connect(m_ui->licenceButton, SIGNAL(clicked()), this, SLOT(showLicence()));
	connect(m_ui->buttonBox, SIGNAL(accepted()), this, SLOT(close()));
}

DlgAbout::~DlgAbout(void)
{
	delete m_ui;
}

void DlgAbout::about(QWidget *parent)
{
	DlgAbout dlg(parent);
	dlg.exec();
}

void DlgAbout::showLicence(void)
{
	DlgLicence::showLicence(this);
}
